# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/status/time_synchronization.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/status/time_synchronization.proto',
  package='blickfeld.protocol.status',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+blickfeld/status/time_synchronization.proto\x12\x19\x62lickfeld.protocol.status\x1a\x17\x62lickfeld/options.proto\"\xb1\x05\n\x13TimeSynchronization\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32\x34.blickfeld.protocol.status.TimeSynchronization.State\x12 \n\x12offset_from_master\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x41\n\x03ntp\x18\x03 \x01(\x0b\x32\x32.blickfeld.protocol.status.TimeSynchronization.NTPH\x00\x12\x41\n\x03ptp\x18\x04 \x01(\x0b\x32\x32.blickfeld.protocol.status.TimeSynchronization.PTPH\x00\x1a\xcf\x01\n\x03PTP\x12\x13\n\x05state\x18\x01 \x01(\tB\x04\xb0\xb5\x18\x01\x12\x16\n\x08\x63lock_id\x18\x02 \x01(\tB\x04\xb0\xb5\x18\x01\x12\x1b\n\rone_way_delay\x18\x03 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fslave_to_master\x18\x04 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0fmaster_to_slave\x18\x05 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1c\n\x0eobserved_drift\x18\x06 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\"\n\x14last_packet_received\x18\x07 \x01(\tB\x04\xb0\xb5\x18\x01\x1a\x8c\x01\n\x03NTP\x12\x1e\n\x10\x66requency_offset\x18\x01 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x18\n\nrms_jitter\x18\x02 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12\x1d\n\x0f\x61llan_deviation\x18\x03 \x01(\x02\x42\x04\xb0\xb5\x18\x01\x12,\n\x1e\x63lock_discipline_time_constant\x18\x04 \x01(\x02\x42\x04\xb0\xb5\x18\x01\">\n\x05State\x12\x0b\n\x07STOPPED\x10\x01\x12\x10\n\x0cINITIALIZING\x10\x02\x12\n\n\x06SYNCED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x0c\n\x04kind\x12\x04\xb0\xb5\x18\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])



_TIMESYNCHRONIZATION_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='blickfeld.protocol.status.TimeSynchronization.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNCED', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=713,
  serialized_end=775,
)
_sym_db.RegisterEnumDescriptor(_TIMESYNCHRONIZATION_STATE)


_TIMESYNCHRONIZATION_PTP = _descriptor.Descriptor(
  name='PTP',
  full_name='blickfeld.protocol.status.TimeSynchronization.PTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_id', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.clock_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_way_delay', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.one_way_delay', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slave_to_master', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.slave_to_master', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_to_slave', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.master_to_slave', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observed_drift', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.observed_drift', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_packet_received', full_name='blickfeld.protocol.status.TimeSynchronization.PTP.last_packet_received', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=568,
)

_TIMESYNCHRONIZATION_NTP = _descriptor.Descriptor(
  name='NTP',
  full_name='blickfeld.protocol.status.TimeSynchronization.NTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frequency_offset', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.frequency_offset', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rms_jitter', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.rms_jitter', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allan_deviation', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.allan_deviation', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock_discipline_time_constant', full_name='blickfeld.protocol.status.TimeSynchronization.NTP.clock_discipline_time_constant', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=711,
)

_TIMESYNCHRONIZATION = _descriptor.Descriptor(
  name='TimeSynchronization',
  full_name='blickfeld.protocol.status.TimeSynchronization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='blickfeld.protocol.status.TimeSynchronization.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset_from_master', full_name='blickfeld.protocol.status.TimeSynchronization.offset_from_master', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ntp', full_name='blickfeld.protocol.status.TimeSynchronization.ntp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptp', full_name='blickfeld.protocol.status.TimeSynchronization.ptp', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TIMESYNCHRONIZATION_PTP, _TIMESYNCHRONIZATION_NTP, ],
  enum_types=[
    _TIMESYNCHRONIZATION_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='blickfeld.protocol.status.TimeSynchronization.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\260\265\030\001'),
  ],
  serialized_start=100,
  serialized_end=789,
)

_TIMESYNCHRONIZATION_PTP.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION_NTP.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION.fields_by_name['state'].enum_type = _TIMESYNCHRONIZATION_STATE
_TIMESYNCHRONIZATION.fields_by_name['ntp'].message_type = _TIMESYNCHRONIZATION_NTP
_TIMESYNCHRONIZATION.fields_by_name['ptp'].message_type = _TIMESYNCHRONIZATION_PTP
_TIMESYNCHRONIZATION_STATE.containing_type = _TIMESYNCHRONIZATION
_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _TIMESYNCHRONIZATION.fields_by_name['ntp'])
_TIMESYNCHRONIZATION.fields_by_name['ntp'].containing_oneof = _TIMESYNCHRONIZATION.oneofs_by_name['kind']
_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _TIMESYNCHRONIZATION.fields_by_name['ptp'])
_TIMESYNCHRONIZATION.fields_by_name['ptp'].containing_oneof = _TIMESYNCHRONIZATION.oneofs_by_name['kind']
DESCRIPTOR.message_types_by_name['TimeSynchronization'] = _TIMESYNCHRONIZATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeSynchronization = _reflection.GeneratedProtocolMessageType('TimeSynchronization', (_message.Message,), {

  'PTP' : _reflection.GeneratedProtocolMessageType('PTP', (_message.Message,), {
    'DESCRIPTOR' : _TIMESYNCHRONIZATION_PTP,
    '__module__' : 'blickfeld.status.time_synchronization_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization.PTP)
    })
  ,

  'NTP' : _reflection.GeneratedProtocolMessageType('NTP', (_message.Message,), {
    'DESCRIPTOR' : _TIMESYNCHRONIZATION_NTP,
    '__module__' : 'blickfeld.status.time_synchronization_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization.NTP)
    })
  ,
  'DESCRIPTOR' : _TIMESYNCHRONIZATION,
  '__module__' : 'blickfeld.status.time_synchronization_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.status.TimeSynchronization)
  })
_sym_db.RegisterMessage(TimeSynchronization)
_sym_db.RegisterMessage(TimeSynchronization.PTP)
_sym_db.RegisterMessage(TimeSynchronization.NTP)


_TIMESYNCHRONIZATION_PTP.fields_by_name['state']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['clock_id']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['one_way_delay']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['slave_to_master']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['master_to_slave']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['observed_drift']._options = None
_TIMESYNCHRONIZATION_PTP.fields_by_name['last_packet_received']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['frequency_offset']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['rms_jitter']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['allan_deviation']._options = None
_TIMESYNCHRONIZATION_NTP.fields_by_name['clock_discipline_time_constant']._options = None
_TIMESYNCHRONIZATION.oneofs_by_name['kind']._options = None
_TIMESYNCHRONIZATION.fields_by_name['offset_from_master']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.stream.connection_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Server(google.protobuf.message.Message):
    """*
    This section defines the status of the network server.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class NetworkStats(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class Channel(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            TOTAL_BYTE_COUNT_FIELD_NUMBER: builtins.int
            BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
            MAXIMUM_BYTES_PER_SECOND_FIELD_NUMBER: builtins.int
            total_byte_count: builtins.int = ...
            bytes_per_second: builtins.float = ...
            maximum_bytes_per_second: builtins.float = ...
            def __init__(self,
                *,
                total_byte_count : typing.Optional[builtins.int] = ...,
                bytes_per_second : typing.Optional[builtins.float] = ...,
                maximum_bytes_per_second : typing.Optional[builtins.float] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"bytes_per_second",b"bytes_per_second",u"maximum_bytes_per_second",b"maximum_bytes_per_second",u"total_byte_count",b"total_byte_count"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"bytes_per_second",b"bytes_per_second",u"maximum_bytes_per_second",b"maximum_bytes_per_second",u"total_byte_count",b"total_byte_count"]) -> None: ...

        SENT_FIELD_NUMBER: builtins.int
        RECEIVED_FIELD_NUMBER: builtins.int
        DROPPED_MESSAGES_FIELD_NUMBER: builtins.int
        @property
        def sent(self) -> global___Server.NetworkStats.Channel: ...
        @property
        def received(self) -> global___Server.NetworkStats.Channel: ...
        dropped_messages: builtins.int = ...
        def __init__(self,
            *,
            sent : typing.Optional[global___Server.NetworkStats.Channel] = ...,
            received : typing.Optional[global___Server.NetworkStats.Channel] = ...,
            dropped_messages : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"dropped_messages",b"dropped_messages",u"received",b"received",u"sent",b"sent"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"dropped_messages",b"dropped_messages",u"received",b"received",u"sent",b"sent"]) -> None: ...

    class Client(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
        NETWORK_STATS_FIELD_NUMBER: builtins.int
        IDENTIFIER_FIELD_NUMBER: builtins.int
        @property
        def subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.stream.connection_pb2.Subscribe]: ...
        @property
        def network_stats(self) -> global___Server.NetworkStats: ...
        identifier: typing.Text = ...
        def __init__(self,
            *,
            subscriptions : typing.Optional[typing.Iterable[blickfeld.stream.connection_pb2.Subscribe]] = ...,
            network_stats : typing.Optional[global___Server.NetworkStats] = ...,
            identifier : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"identifier",b"identifier",u"network_stats",b"network_stats"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"identifier",b"identifier",u"network_stats",b"network_stats",u"subscriptions",b"subscriptions"]) -> None: ...

    CLIENTS_FIELD_NUMBER: builtins.int
    NETWORK_STATS_FIELD_NUMBER: builtins.int
    @property
    def clients(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Server.Client]: ...
    @property
    def network_stats(self) -> global___Server.NetworkStats: ...
    def __init__(self,
        *,
        clients : typing.Optional[typing.Iterable[global___Server.Client]] = ...,
        network_stats : typing.Optional[global___Server.NetworkStats] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"network_stats",b"network_stats"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"clients",b"clients",u"network_stats",b"network_stats"]) -> None: ...
global___Server = Server



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.algorithm_pb2
import blickfeld.config.scan_pattern_pb2
import blickfeld.data.frame_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Subscribe(google.protobuf.message.Message):
    """*
    This section describes the different streams to which it is possible to subscribe.
    A stream regularly provides data or status updates for the user. The events will not be pushed automatically to the BSL; the client has to retrieve them.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class PointCloud(google.protobuf.message.Message):
        """*
        This request is used for subscribing to a point cloud stream.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REFERENCE_FRAME_FIELD_NUMBER: builtins.int
        FILTER_FIELD_NUMBER: builtins.int
        ALGORITHMS_FIELD_NUMBER: builtins.int
        PREPEND_ADVANCED_CONFIG_ALGORITHMS_FIELD_NUMBER: builtins.int
        @property
        def reference_frame(self) -> blickfeld.data.frame_pb2.Frame:
            """<blockquote>Introduced in BSL v2.10 and firmware v1.9</blockquote> If present, only fields that are set in this message and submessages will be present in the point cloud. If less fields are requested, the Protobuf encoding and network transport time can reduce significantly."""
            pass
        @property
        def filter(self) -> blickfeld.config.scan_pattern_pb2.ScanPattern.Filter:
            """<blockquote>Introduced in BSL v2.10 and firmware v1.9</blockquote> Refer to [ScanPattern.Filter](#blickfeld.protocol.config.ScanPattern.Filter). Overrides parameters of scan pattern."""
            pass
        @property
        def algorithms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.config.algorithm_pb2.Algorithm]:
            """<blockquote>Introduced in BSL v2.17 and firmware v1.16</blockquote> Refer to [config.Algorithm](#blickfeld.protocol.config.Algorithm). Sets algorithms, which are initialized, configured for the stream and are executed on each frame in the post-processing on the device."""
            pass
        prepend_advanced_config_algorithms: builtins.bool = ...
        """<blockquote>Introduced in BSL v2.17 and firmware v1.16</blockquote> With the server.default_point_cloud_subscription algorithms can be persisted on the device and they are by default prepended to the list of sent algorithms in the subscribe request. This behaviour can be disabled with this field to e.g. disable or overwrite all algorithms."""

        def __init__(self,
            *,
            reference_frame : typing.Optional[blickfeld.data.frame_pb2.Frame] = ...,
            filter : typing.Optional[blickfeld.config.scan_pattern_pb2.ScanPattern.Filter] = ...,
            algorithms : typing.Optional[typing.Iterable[blickfeld.config.algorithm_pb2.Algorithm]] = ...,
            prepend_advanced_config_algorithms : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"filter",b"filter",u"prepend_advanced_config_algorithms",b"prepend_advanced_config_algorithms",u"reference_frame",b"reference_frame"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"algorithms",b"algorithms",u"filter",b"filter",u"prepend_advanced_config_algorithms",b"prepend_advanced_config_algorithms",u"reference_frame",b"reference_frame"]) -> None: ...

    class Status(google.protobuf.message.Message):
        """*
        This request is used for subscribing to a status stream.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class RawFile(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.13 and firmware v1.13

        This request is used for subscribing to a raw file stream.
        The requested stream is directly packed in the Blickfeld data format and only raw bytes are sent to the client, which it should write sequentially in a file.
        An [Unsubscribe](#blickfeld.protocol.stream.Unsubscribe) request with the same request data must be sent to properly end the file stream.
        The request raw file stream is ended with an [EndOfStream](#blickfeld.protocol.stream.Event.EndOfStream) event.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        POINT_CLOUD_FIELD_NUMBER: builtins.int
        @property
        def point_cloud(self) -> global___Subscribe.PointCloud:
            """Subscribe to a raw point cloud stream. Refer to [Subscribe.PointCloud](#blickfeld.protocol.stream.Subscribe.PointCloud)."""
            pass
        def __init__(self,
            *,
            point_cloud : typing.Optional[global___Subscribe.PointCloud] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"point_cloud",b"point_cloud"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"point_cloud",b"point_cloud"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["point_cloud"]]: ...

    class IMU(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.18 and firmware v1.19

        The Cube has an on-board IMU, which can be used for e.g. mapping applications or static auto-leveling.
        A stream can be requested with this subscription.
        The default rate is approx. 1.125 kHz and is provided in bursts.
        The timestamps inside the protocol are synchronized to the ones in point cloud frames.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        PACKED_FORMAT_FIELD_NUMBER: builtins.int
        packed_format: builtins.bool = ...
        """Request a packed binary format. This is currently used for efficent Python numpy decoding."""

        def __init__(self,
            *,
            packed_format : typing.Optional[builtins.bool] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"packed_format",b"packed_format"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"packed_format",b"packed_format"]) -> None: ...

    class Developer(google.protobuf.message.Message):
        """*
        Internal use only
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    POINT_CLOUD_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEVELOPER_FIELD_NUMBER: builtins.int
    RAW_FILE_FIELD_NUMBER: builtins.int
    IMU_FIELD_NUMBER: builtins.int
    @property
    def point_cloud(self) -> global___Subscribe.PointCloud:
        """Refer to [Subscribe.PointCloud](#blickfeld.protocol.stream.Subscribe.PointCloud)"""
        pass
    @property
    def status(self) -> global___Subscribe.Status:
        """Refer to [Subscribe.Status](#blickfeld.protocol.stream.Subscribe.Status)"""
        pass
    @property
    def developer(self) -> global___Subscribe.Developer:
        """Refer to [Subscribe.Developer](#blickfeld.protocol.stream.Subscribe.Developer)"""
        pass
    @property
    def raw_file(self) -> global___Subscribe.RawFile:
        """Refer to [Subscribe.RawFile](#blickfeld.protocol.stream.Subscribe.RawFile)"""
        pass
    @property
    def imu(self) -> global___Subscribe.IMU:
        """<blockquote>Introduced in BSL v2.18 and firmware v1.19</blockquote> Refer to [Subscribe.IMU](#blickfeld.protocol.stream.Subscribe.IMU)"""
        pass
    def __init__(self,
        *,
        point_cloud : typing.Optional[global___Subscribe.PointCloud] = ...,
        status : typing.Optional[global___Subscribe.Status] = ...,
        developer : typing.Optional[global___Subscribe.Developer] = ...,
        raw_file : typing.Optional[global___Subscribe.RawFile] = ...,
        imu : typing.Optional[global___Subscribe.IMU] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"developer",b"developer",u"imu",b"imu",u"point_cloud",b"point_cloud",u"raw_file",b"raw_file",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"developer",b"developer",u"imu",b"imu",u"point_cloud",b"point_cloud",u"raw_file",b"raw_file",u"status",b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["point_cloud","status","developer","raw_file","imu"]]: ...
global___Subscribe = Subscribe



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/options.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from blickfeld.config import generate_pb2 as blickfeld_dot_config_dot_generate__pb2
from blickfeld.config import secure_pb2 as blickfeld_dot_config_dot_secure__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/options.proto',
  package='blickfeld.protocol',
  syntax='proto2',
  serialized_options=b'H\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x62lickfeld/options.proto\x12\x12\x62lickfeld.protocol\x1a google/protobuf/descriptor.proto\x1a\x1f\x62lickfeld/config/generate.proto\x1a\x1d\x62lickfeld/config/secure.proto:?\n\x0foptional_one_of\x12\x1d.google.protobuf.OneofOptions\x18\xd6\x86\x03 \x01(\x08:\x05\x66\x61lse:4\n\x05\x64_min\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x01:\x04-inf:3\n\x05\x64_max\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x01:\x03inf:;\n\x06length\x12\x1d.google.protobuf.FieldOptions\x18\xd4\x86\x03 \x01(\x11:\n2147483647:2\n\x05regex\x12\x1d.google.protobuf.FieldOptions\x18\xd5\x86\x03 \x01(\t:\x02.*:8\n\x08optional\x12\x1d.google.protobuf.FieldOptions\x18\xd6\x86\x03 \x01(\x08:\x05\x66\x61lse:<\n\x0c\x61llow_sparse\x12\x1d.google.protobuf.FieldOptions\x18\xd7\x86\x03 \x01(\x08:\x05\x66\x61lse:6\n\nmin_length\x12\x1d.google.protobuf.FieldOptions\x18\xd8\x86\x03 \x01(\x11:\x01\x30:?\n\nmax_length\x12\x1d.google.protobuf.FieldOptions\x18\xd9\x86\x03 \x01(\x11:\n2147483647:8\n\x0flegacy_field_id\x12\x1d.google.protobuf.FieldOptions\x18\xda\x86\x03 \x01(\x04:-\n\x04unit\x12\x1d.google.protobuf.FieldOptions\x18\xdb\x86\x03 \x01(\t:0\n\x07ui_unit\x12\x1d.google.protobuf.FieldOptions\x18\xdc\x86\x03 \x01(\t:4\n\x08ui_scale\x12\x1d.google.protobuf.FieldOptions\x18\xdd\x86\x03 \x01(\x01:\x01\x31:=\n\x11ui_decimal_places\x12\x1d.google.protobuf.FieldOptions\x18\xde\x86\x03 \x01(\r:\x01\x30:]\n\x06\x65_desc\x12\x1f.google.protobuf.MessageOptions\x18\xe0\xd4\x03 \x01(\t:*No additional error description available.:1\n\x04help\x12\x1f.google.protobuf.MessageOptions\x18\xe1\xd4\x03 \x01(\t:\x00:T\n\x06secure\x12\x1f.google.protobuf.MessageOptions\x18\xe2\xd4\x03 \x01(\x0b\x32!.blickfeld.protocol.config.Secure:X\n\x08generate\x12\x1f.google.protobuf.MessageOptions\x18\xe3\xd4\x03 \x01(\x0b\x32#.blickfeld.protocol.config.GenerateB\x02H\x02'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,blickfeld_dot_config_dot_generate__pb2.DESCRIPTOR,blickfeld_dot_config_dot_secure__pb2.DESCRIPTOR,])


OPTIONAL_ONE_OF_FIELD_NUMBER = 50006
optional_one_of = _descriptor.FieldDescriptor(
  name='optional_one_of', full_name='blickfeld.protocol.optional_one_of', index=0,
  number=50006, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
D_MIN_FIELD_NUMBER = 50000
d_min = _descriptor.FieldDescriptor(
  name='d_min', full_name='blickfeld.protocol.d_min', index=1,
  number=50000, type=1, cpp_type=5, label=1,
  has_default_value=True, default_value=-1e10000,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
D_MAX_FIELD_NUMBER = 50001
d_max = _descriptor.FieldDescriptor(
  name='d_max', full_name='blickfeld.protocol.d_max', index=2,
  number=50001, type=1, cpp_type=5, label=1,
  has_default_value=True, default_value=1e10000,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
LENGTH_FIELD_NUMBER = 50004
length = _descriptor.FieldDescriptor(
  name='length', full_name='blickfeld.protocol.length', index=3,
  number=50004, type=17, cpp_type=1, label=1,
  has_default_value=True, default_value=2147483647,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REGEX_FIELD_NUMBER = 50005
regex = _descriptor.FieldDescriptor(
  name='regex', full_name='blickfeld.protocol.regex', index=4,
  number=50005, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b".*".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
OPTIONAL_FIELD_NUMBER = 50006
optional = _descriptor.FieldDescriptor(
  name='optional', full_name='blickfeld.protocol.optional', index=5,
  number=50006, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ALLOW_SPARSE_FIELD_NUMBER = 50007
allow_sparse = _descriptor.FieldDescriptor(
  name='allow_sparse', full_name='blickfeld.protocol.allow_sparse', index=6,
  number=50007, type=8, cpp_type=7, label=1,
  has_default_value=True, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MIN_LENGTH_FIELD_NUMBER = 50008
min_length = _descriptor.FieldDescriptor(
  name='min_length', full_name='blickfeld.protocol.min_length', index=7,
  number=50008, type=17, cpp_type=1, label=1,
  has_default_value=True, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MAX_LENGTH_FIELD_NUMBER = 50009
max_length = _descriptor.FieldDescriptor(
  name='max_length', full_name='blickfeld.protocol.max_length', index=8,
  number=50009, type=17, cpp_type=1, label=1,
  has_default_value=True, default_value=2147483647,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
LEGACY_FIELD_ID_FIELD_NUMBER = 50010
legacy_field_id = _descriptor.FieldDescriptor(
  name='legacy_field_id', full_name='blickfeld.protocol.legacy_field_id', index=9,
  number=50010, type=4, cpp_type=4, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNIT_FIELD_NUMBER = 50011
unit = _descriptor.FieldDescriptor(
  name='unit', full_name='blickfeld.protocol.unit', index=10,
  number=50011, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UI_UNIT_FIELD_NUMBER = 50012
ui_unit = _descriptor.FieldDescriptor(
  name='ui_unit', full_name='blickfeld.protocol.ui_unit', index=11,
  number=50012, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UI_SCALE_FIELD_NUMBER = 50013
ui_scale = _descriptor.FieldDescriptor(
  name='ui_scale', full_name='blickfeld.protocol.ui_scale', index=12,
  number=50013, type=1, cpp_type=5, label=1,
  has_default_value=True, default_value=float(1),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UI_DECIMAL_PLACES_FIELD_NUMBER = 50014
ui_decimal_places = _descriptor.FieldDescriptor(
  name='ui_decimal_places', full_name='blickfeld.protocol.ui_decimal_places', index=13,
  number=50014, type=13, cpp_type=3, label=1,
  has_default_value=True, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
E_DESC_FIELD_NUMBER = 60000
e_desc = _descriptor.FieldDescriptor(
  name='e_desc', full_name='blickfeld.protocol.e_desc', index=14,
  number=60000, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b"No additional error description available.".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
HELP_FIELD_NUMBER = 60001
help = _descriptor.FieldDescriptor(
  name='help', full_name='blickfeld.protocol.help', index=15,
  number=60001, type=9, cpp_type=9, label=1,
  has_default_value=True, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SECURE_FIELD_NUMBER = 60002
secure = _descriptor.FieldDescriptor(
  name='secure', full_name='blickfeld.protocol.secure', index=16,
  number=60002, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GENERATE_FIELD_NUMBER = 60003
generate = _descriptor.FieldDescriptor(
  name='generate', full_name='blickfeld.protocol.generate', index=17,
  number=60003, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.extensions_by_name['optional_one_of'] = optional_one_of
DESCRIPTOR.extensions_by_name['d_min'] = d_min
DESCRIPTOR.extensions_by_name['d_max'] = d_max
DESCRIPTOR.extensions_by_name['length'] = length
DESCRIPTOR.extensions_by_name['regex'] = regex
DESCRIPTOR.extensions_by_name['optional'] = optional
DESCRIPTOR.extensions_by_name['allow_sparse'] = allow_sparse
DESCRIPTOR.extensions_by_name['min_length'] = min_length
DESCRIPTOR.extensions_by_name['max_length'] = max_length
DESCRIPTOR.extensions_by_name['legacy_field_id'] = legacy_field_id
DESCRIPTOR.extensions_by_name['unit'] = unit
DESCRIPTOR.extensions_by_name['ui_unit'] = ui_unit
DESCRIPTOR.extensions_by_name['ui_scale'] = ui_scale
DESCRIPTOR.extensions_by_name['ui_decimal_places'] = ui_decimal_places
DESCRIPTOR.extensions_by_name['e_desc'] = e_desc
DESCRIPTOR.extensions_by_name['help'] = help
DESCRIPTOR.extensions_by_name['secure'] = secure
DESCRIPTOR.extensions_by_name['generate'] = generate
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(optional_one_of)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(d_min)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(d_max)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(length)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(regex)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(optional)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(allow_sparse)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(min_length)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(max_length)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(legacy_field_id)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(unit)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(ui_unit)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(ui_scale)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(ui_decimal_places)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(e_desc)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(help)
secure.message_type = blickfeld_dot_config_dot_secure__pb2._SECURE
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(secure)
generate.message_type = blickfeld_dot_config_dot_generate__pb2._GENERATE
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(generate)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.status.imu_pb2
import blickfeld.status.scanner_pb2
import blickfeld.status.server_pb2
import blickfeld.status.temperature_pb2
import blickfeld.status.time_synchronization_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Status(google.protobuf.message.Message):
    """*
    This section contains the status messages of the two deflection mirrors and the temperature sensors in the device.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SCANNER_FIELD_NUMBER: builtins.int
    TEMPERATURES_FIELD_NUMBER: builtins.int
    SERVER_FIELD_NUMBER: builtins.int
    IMU_FIELD_NUMBER: builtins.int
    TIME_SYNCHRONIZATION_FIELD_NUMBER: builtins.int
    @property
    def scanner(self) -> blickfeld.status.scanner_pb2.Scanner:
        """Refer to [Scanner](#blickfeld.protocol.status.scanner.Scanner)"""
        pass
    @property
    def temperatures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[blickfeld.status.temperature_pb2.Temperature]:
        """Refer to [Temperature](#blickfeld.protocol.status.temperature.Temperature)"""
        pass
    @property
    def server(self) -> blickfeld.status.server_pb2.Server:
        """Refer to [Client](#blickfeld.protocol.status.server.Server)"""
        pass
    @property
    def imu(self) -> blickfeld.status.imu_pb2.IMU:
        """<blockquote>Introduced in BSL v2.18 and firmware v1.19</blockquote> Refer to [IMU](#blickfeld.protocol.status.IMU)"""
        pass
    @property
    def time_synchronization(self) -> blickfeld.status.time_synchronization_pb2.TimeSynchronization:
        """<blockquote>Introduced in BSL v2.18 and firmware v1.19</blockquote> Refer to [TimeSynchronization](#blickfeld.protocol.status.TimeSynchronization)"""
        pass
    def __init__(self,
        *,
        scanner : typing.Optional[blickfeld.status.scanner_pb2.Scanner] = ...,
        temperatures : typing.Optional[typing.Iterable[blickfeld.status.temperature_pb2.Temperature]] = ...,
        server : typing.Optional[blickfeld.status.server_pb2.Server] = ...,
        imu : typing.Optional[blickfeld.status.imu_pb2.IMU] = ...,
        time_synchronization : typing.Optional[blickfeld.status.time_synchronization_pb2.TimeSynchronization] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"imu",b"imu",u"scanner",b"scanner",u"server",b"server",u"time_synchronization",b"time_synchronization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"imu",b"imu",u"scanner",b"scanner",u"server",b"server",u"temperatures",b"temperatures",u"time_synchronization",b"time_synchronization"]) -> None: ...
global___Status = Status



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Algorithm(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.17 and firmware v1.18

    This section describes the additional data output of on-device algorithms.
    The data is attached to the frame.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class BackgroundSubtraction(google.protobuf.message.Message):
        """*
        The description of the algorithm can be found at [config.Algorithm.BackgroundSubtraction](#blickfeld.protocol.config.Algorithm.BackgroundSubtraction).

        The algorithm does not output any additional information.
        It subtracts returns from the main frame.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class NeighborFilter(google.protobuf.message.Message):
        """*
        The description of the algorithm can be found at [config.Algorithm.NeighborFilter](#blickfeld.protocol.config.Algorithm.NeighborFilter).

        The algorithm does not output any additional information.
        It subtracts returns from the main frame.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class StaticTransformation(google.protobuf.message.Message):
        """*
        The description of the algorithm can be found at [config.Algorithm.StaticTransformation](#blickfeld.protocol.config.Algorithm.StaticTransformation).

        The algorithm does not output any additional information.
        It transforms the cartesian coordinates in the frame.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    BACKGROUND_SUBTRACTION_FIELD_NUMBER: builtins.int
    NEIGHBOR_FILTER_FIELD_NUMBER: builtins.int
    STATIC_TRANSFORMATION_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    @property
    def background_subtraction(self) -> global___Algorithm.BackgroundSubtraction:
        """Refer to [BackgroundSubtraction](#blickfeld.protocol.data.Algorithm.BackgroundSubtraction)."""
        pass
    @property
    def neighbor_filter(self) -> global___Algorithm.NeighborFilter:
        """Refer to [NeighborFilter](#blickfeld.protocol.data.Algorithm.NeighborFilter)."""
        pass
    @property
    def static_transformation(self) -> global___Algorithm.StaticTransformation:
        """Refer to [StaticTransformation](#blickfeld.protocol.data.Algorithm.StaticTransformation)."""
        pass
    execution_time: builtins.float = ...
    """Execution time of the algorithm in [s]"""

    def __init__(self,
        *,
        background_subtraction : typing.Optional[global___Algorithm.BackgroundSubtraction] = ...,
        neighbor_filter : typing.Optional[global___Algorithm.NeighborFilter] = ...,
        static_transformation : typing.Optional[global___Algorithm.StaticTransformation] = ...,
        execution_time : typing.Optional[builtins.float] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"algo",b"algo",u"background_subtraction",b"background_subtraction",u"execution_time",b"execution_time",u"neighbor_filter",b"neighbor_filter",u"static_transformation",b"static_transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"algo",b"algo",u"background_subtraction",b"background_subtraction",u"execution_time",b"execution_time",u"neighbor_filter",b"neighbor_filter",u"static_transformation",b"static_transformation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"algo",b"algo"]) -> typing.Optional[typing_extensions.Literal["background_subtraction","neighbor_filter","static_transformation"]]: ...
global___Algorithm = Algorithm



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MessageHeader(google.protobuf.message.Message):
    """*
    Metadata for a Protobuf message.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROJECT_UUID_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    PROJECT_NAME_FIELD_NUMBER: builtins.int
    project_uuid: typing.Text = ...
    """UUID of the project."""

    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of message construction."""
        pass
    project_name: typing.Text = ...
    """the name of the project as defined by the user"""

    def __init__(self,
        *,
        project_uuid : typing.Text = ...,
        timestamp : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        project_name : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"timestamp",b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"project_name",b"project_name",u"project_uuid",b"project_uuid",u"timestamp",b"timestamp"]) -> None: ...
global___MessageHeader = MessageHeader



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.data.imu_pb2
import blickfeld.data.point_cloud_pb2
import blickfeld.status.main_pb2
import blickfeld.stream.connection_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Event(google.protobuf.message.Message):
    """*
    This section describes the events of streams.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Developer(google.protobuf.message.Message):
        """*
        Internal use only
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        def __init__(self,
            ) -> None: ...

    class EndOfStream(google.protobuf.message.Message):
        """*
        > Introduced in BSL v2.13 and firmware v1.13

        Event to indicate the end of stream.
        This is called after an [Unsubscribe](#blickfeld.protocol.stream.Unsubscribe) request.
        No further events will arrive for the subscribed stream after this event.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        SUBSCRIPTION_FIELD_NUMBER: builtins.int
        @property
        def subscription(self) -> blickfeld.stream.connection_pb2.Subscribe:
            """Ended subscription. Refer to [Subscribe](#blickfeld.protocol.stream.Subscribe)."""
            pass
        def __init__(self,
            *,
            subscription : typing.Optional[blickfeld.stream.connection_pb2.Subscribe] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"subscription",b"subscription"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"subscription",b"subscription"]) -> None: ...

    POINT_CLOUD_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEVELOPER_FIELD_NUMBER: builtins.int
    RAW_FILE_FIELD_NUMBER: builtins.int
    END_OF_STREAM_FIELD_NUMBER: builtins.int
    IMU_FIELD_NUMBER: builtins.int
    @property
    def point_cloud(self) -> blickfeld.data.point_cloud_pb2.PointCloud:
        """Refer to [PointCloud](#blickfeld.protocol.data.PointCloud)"""
        pass
    @property
    def status(self) -> blickfeld.status.main_pb2.Status:
        """Refer to [Status](#blickfeld.protocol.Status)"""
        pass
    @property
    def developer(self) -> global___Event.Developer:
        """Refer to [Event.Developer](#blickfeld.protocol.stream.Event.Developer)"""
        pass
    raw_file: builtins.bytes = ...
    """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Raw bytes, which should be written sequentially in a file. Refer to [RawFile](#blickfeld.protocol.stream.Subscribe.RawFile)."""

    @property
    def end_of_stream(self) -> global___Event.EndOfStream:
        """<blockquote>Introduced in BSL v2.13 and firmware v1.13</blockquote> Refer to [EndOfStream](#blickfeld.protocol.stream.Event.EndOfStream)"""
        pass
    @property
    def imu(self) -> blickfeld.data.imu_pb2.IMU:
        """<blockquote>Introduced in BSL v2.18 and firmware v1.19</blockquote> Refer to [IMU](#blickfeld.protocol.data.IMU)"""
        pass
    def __init__(self,
        *,
        point_cloud : typing.Optional[blickfeld.data.point_cloud_pb2.PointCloud] = ...,
        status : typing.Optional[blickfeld.status.main_pb2.Status] = ...,
        developer : typing.Optional[global___Event.Developer] = ...,
        raw_file : typing.Optional[builtins.bytes] = ...,
        end_of_stream : typing.Optional[global___Event.EndOfStream] = ...,
        imu : typing.Optional[blickfeld.data.imu_pb2.IMU] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"data",b"data",u"developer",b"developer",u"end_of_stream",b"end_of_stream",u"imu",b"imu",u"point_cloud",b"point_cloud",u"raw_file",b"raw_file",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"developer",b"developer",u"end_of_stream",b"end_of_stream",u"imu",b"imu",u"point_cloud",b"point_cloud",u"raw_file",b"raw_file",u"status",b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"data",b"data"]) -> typing.Optional[typing_extensions.Literal["point_cloud","status","developer","raw_file","end_of_stream","imu"]]: ...
global___Event = Event



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/object.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from bf_proto.percept.common import geometric_shapes_pb2 as bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2
from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/object.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"bf_proto/percept/data/object.proto\x12\x16\x62lickfeld.percept.data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.bf_proto/percept/common/geometric_shapes.proto\x1a&bf_proto/percept/common/geometry.proto\"\x95\x04\n\x06Object\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12,\n\x04pose\x18\x03 \x01(\x0b\x32\x1e.blickfeld.percept.common.Pose\x12:\n\x0flinear_velocity\x18\x04 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12;\n\x10\x61ngular_velocity\x18\x05 \x01(\x0b\x32!.blickfeld.percept.common.Vector3\x12.\n\x05shape\x18\x06 \x01(\x0b\x32\x1f.blickfeld.percept.common.Shape\x12\x45\n\x0e\x63lassification\x18\x07 \x01(\x0b\x32-.blickfeld.percept.data.Object.Classification\x12,\n\x04path\x18\x08 \x03(\x0b\x32\x1e.blickfeld.percept.common.Pose\x1a\x81\x01\n\x0e\x43lassification\x12\x41\n\x05types\x18\x01 \x03(\x0b\x32\x32.blickfeld.percept.data.Object.Classification.Type\x1a,\n\x04Type\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\nconfidence\x18\x02 \x01(\x02J\x04\x08\x01\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_OBJECT_CLASSIFICATION_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='blickfeld.percept.data.Object.Classification.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blickfeld.percept.data.Object.Classification.Type.id', index=0,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='blickfeld.percept.data.Object.Classification.Type.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=717,
)

_OBJECT_CLASSIFICATION = _descriptor.Descriptor(
  name='Classification',
  full_name='blickfeld.percept.data.Object.Classification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='blickfeld.percept.data.Object.Classification.types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_CLASSIFICATION_TYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=717,
)

_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='blickfeld.percept.data.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blickfeld.percept.data.Object.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='blickfeld.percept.data.Object.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='blickfeld.percept.data.Object.pose', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='blickfeld.percept.data.Object.linear_velocity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='blickfeld.percept.data.Object.angular_velocity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='blickfeld.percept.data.Object.shape', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='classification', full_name='blickfeld.percept.data.Object.classification', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='blickfeld.percept.data.Object.path', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_CLASSIFICATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=717,
)

_OBJECT_CLASSIFICATION_TYPE.containing_type = _OBJECT_CLASSIFICATION
_OBJECT_CLASSIFICATION.fields_by_name['types'].message_type = _OBJECT_CLASSIFICATION_TYPE
_OBJECT_CLASSIFICATION.containing_type = _OBJECT
_OBJECT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OBJECT.fields_by_name['pose'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
_OBJECT.fields_by_name['linear_velocity'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_OBJECT.fields_by_name['angular_velocity'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._VECTOR3
_OBJECT.fields_by_name['shape'].message_type = bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2._SHAPE
_OBJECT.fields_by_name['classification'].message_type = _OBJECT_CLASSIFICATION
_OBJECT.fields_by_name['path'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._POSE
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {

  'Classification' : _reflection.GeneratedProtocolMessageType('Classification', (_message.Message,), {

    'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
      'DESCRIPTOR' : _OBJECT_CLASSIFICATION_TYPE,
      '__module__' : 'bf_proto.percept.data.object_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object.Classification.Type)
      })
    ,
    'DESCRIPTOR' : _OBJECT_CLASSIFICATION,
    '__module__' : 'bf_proto.percept.data.object_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object.Classification)
    })
  ,
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'bf_proto.percept.data.object_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.Object)
  })
_sym_db.RegisterMessage(Object)
_sym_db.RegisterMessage(Object.Classification)
_sym_db.RegisterMessage(Object.Classification.Type)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.metadata_pb2
import bf_proto.percept.data.object_pb2
import bf_proto.percept.data.point_cloud_transform_pb2
import bf_proto.percept.data.state_pb2
import bf_proto.percept.data.zone_algorithm_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class StateList(google.protobuf.message.Message):
    """*
    A message containing one or more states.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    STATES_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    @property
    def states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.state_pb2.State]:
        """List of states."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        states : typing.Optional[typing.Iterable[bf_proto.percept.data.state_pb2.State]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"states",b"states"]) -> None: ...
global___StateList = StateList

class ObjectList(google.protobuf.message.Message):
    """*
    A message that can contain one or more objects.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    REFERENCE_FRAME_FIELD_NUMBER: builtins.int
    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    reference_frame: typing.Text = ...
    """The reference frame the geometry is expressed in."""

    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.object_pb2.Object]:
        """List of objects."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        reference_frame : typing.Text = ...,
        objects : typing.Optional[typing.Iterable[bf_proto.percept.data.object_pb2.Object]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"objects",b"objects",u"reference_frame",b"reference_frame"]) -> None: ...
global___ObjectList = ObjectList

class ZoneAlgorithmList(google.protobuf.message.Message):
    """*
    A message containing one or more zone algorithms.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    REFERENCE_FRAME_FIELD_NUMBER: builtins.int
    ZONE_ALGORITHMS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    reference_frame: typing.Text = ...
    """The reference frame of the zone geometry is expressed in."""

    @property
    def zone_algorithms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.zone_algorithm_pb2.ZoneAlgorithm]:
        """List of zones algorithms."""
        pass
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        reference_frame : typing.Text = ...,
        zone_algorithms : typing.Optional[typing.Iterable[bf_proto.percept.data.zone_algorithm_pb2.ZoneAlgorithm]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"reference_frame",b"reference_frame",u"zone_algorithms",b"zone_algorithms"]) -> None: ...
global___ZoneAlgorithmList = ZoneAlgorithmList

class PointCloudTransformList(google.protobuf.message.Message):
    """*
    A message containing one or more point cloud transformations.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEADER_FIELD_NUMBER: builtins.int
    POINT_CLOUD_TRANSFORMS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> bf_proto.percept.common.metadata_pb2.MessageHeader: ...
    @property
    def point_cloud_transforms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bf_proto.percept.data.point_cloud_transform_pb2.PointCloudTransform]: ...
    def __init__(self,
        *,
        header : typing.Optional[bf_proto.percept.common.metadata_pb2.MessageHeader] = ...,
        point_cloud_transforms : typing.Optional[typing.Iterable[bf_proto.percept.data.point_cloud_transform_pb2.PointCloudTransform]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"header",b"header",u"point_cloud_transforms",b"point_cloud_transforms"]) -> None: ...
global___PointCloudTransformList = PointCloudTransformList



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/zone_algorithm.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bf_proto.percept.common import geometric_shapes_pb2 as bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2
from bf_proto.percept.common import geometry_pb2 as bf__proto_dot_percept_dot_common_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/zone_algorithm.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*bf_proto/percept/data/zone_algorithm.proto\x12\x16\x62lickfeld.percept.data\x1a.bf_proto/percept/common/geometric_shapes.proto\x1a&bf_proto/percept/common/geometry.proto\"\x8e\x07\n\rZoneAlgorithm\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12.\n\x05shape\x18\x03 \x01(\x0b\x32\x1f.blickfeld.percept.common.Shape\x12^\n\x17\x63urrent_objects_counter\x18\x04 \x01(\x0b\x32;.blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounterH\x00\x12X\n\x14pass_through_counter\x18\x05 \x01(\x0b\x32\x38.blickfeld.percept.data.ZoneAlgorithm.PassThroughCounterH\x00\x12p\n appearance_disappearance_counter\x18\x06 \x01(\x0b\x32\x44.blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounterH\x00\x12\x42\n\x08security\x18\x07 \x01(\x0b\x32..blickfeld.percept.data.ZoneAlgorithm.SecurityH\x00\x12\x44\n\toccupancy\x18\x08 \x01(\x0b\x32/.blickfeld.percept.data.ZoneAlgorithm.OccupancyH\x00\x12>\n\x06volume\x18\t \x01(\x0b\x32,.blickfeld.percept.data.ZoneAlgorithm.VolumeH\x00\x1a\x17\n\x15\x43urrentObjectsCounter\x1a_\n\x12PassThroughCounter\x12/\n\x07inbound\x18\x01 \x01(\x0b\x32\x1e.blickfeld.percept.common.Axis\x12\x18\n\x10\x61\x63\x63umulate_count\x18\x02 \x01(\x08\x1a:\n\x1e\x41ppearanceDisappearanceCounter\x12\x18\n\x10\x61\x63\x63umulate_count\x18\x01 \x01(\x08\x1a\x1e\n\x08Security\x12\x12\n\nmin_points\x18\x01 \x01(\r\x1a\x1f\n\tOccupancy\x12\x12\n\nmin_points\x18\x01 \x01(\r\x1a\x32\n\x06Volume\x12\x12\n\nresolution\x18\x01 \x01(\x02\x12\x14\n\x0c\x65mpty_volume\x18\x02 \x01(\x02\x42\x10\n\x0e\x61lgorithm_typeb\x06proto3'
  ,
  dependencies=[bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2.DESCRIPTOR,bf__proto_dot_percept_dot_common_dot_geometry__pb2.DESCRIPTOR,])




_ZONEALGORITHM_CURRENTOBJECTSCOUNTER = _descriptor.Descriptor(
  name='CurrentObjectsCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=777,
)

_ZONEALGORITHM_PASSTHROUGHCOUNTER = _descriptor.Descriptor(
  name='PassThroughCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inbound', full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter.inbound', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulate_count', full_name='blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter.accumulate_count', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=874,
)

_ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER = _descriptor.Descriptor(
  name='AppearanceDisappearanceCounter',
  full_name='blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accumulate_count', full_name='blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter.accumulate_count', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=934,
)

_ZONEALGORITHM_SECURITY = _descriptor.Descriptor(
  name='Security',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Security',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_points', full_name='blickfeld.percept.data.ZoneAlgorithm.Security.min_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=966,
)

_ZONEALGORITHM_OCCUPANCY = _descriptor.Descriptor(
  name='Occupancy',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Occupancy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_points', full_name='blickfeld.percept.data.ZoneAlgorithm.Occupancy.min_points', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=999,
)

_ZONEALGORITHM_VOLUME = _descriptor.Descriptor(
  name='Volume',
  full_name='blickfeld.percept.data.ZoneAlgorithm.Volume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resolution', full_name='blickfeld.percept.data.ZoneAlgorithm.Volume.resolution', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='empty_volume', full_name='blickfeld.percept.data.ZoneAlgorithm.Volume.empty_volume', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1051,
)

_ZONEALGORITHM = _descriptor.Descriptor(
  name='ZoneAlgorithm',
  full_name='blickfeld.percept.data.ZoneAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blickfeld.percept.data.ZoneAlgorithm.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='blickfeld.percept.data.ZoneAlgorithm.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='blickfeld.percept.data.ZoneAlgorithm.shape', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_objects_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.current_objects_counter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pass_through_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.pass_through_counter', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appearance_disappearance_counter', full_name='blickfeld.percept.data.ZoneAlgorithm.appearance_disappearance_counter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security', full_name='blickfeld.percept.data.ZoneAlgorithm.security', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='blickfeld.percept.data.ZoneAlgorithm.occupancy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='blickfeld.percept.data.ZoneAlgorithm.volume', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ZONEALGORITHM_CURRENTOBJECTSCOUNTER, _ZONEALGORITHM_PASSTHROUGHCOUNTER, _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER, _ZONEALGORITHM_SECURITY, _ZONEALGORITHM_OCCUPANCY, _ZONEALGORITHM_VOLUME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='algorithm_type', full_name='blickfeld.percept.data.ZoneAlgorithm.algorithm_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=159,
  serialized_end=1069,
)

_ZONEALGORITHM_CURRENTOBJECTSCOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_PASSTHROUGHCOUNTER.fields_by_name['inbound'].message_type = bf__proto_dot_percept_dot_common_dot_geometry__pb2._AXIS
_ZONEALGORITHM_PASSTHROUGHCOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_SECURITY.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_OCCUPANCY.containing_type = _ZONEALGORITHM
_ZONEALGORITHM_VOLUME.containing_type = _ZONEALGORITHM
_ZONEALGORITHM.fields_by_name['shape'].message_type = bf__proto_dot_percept_dot_common_dot_geometric__shapes__pb2._SHAPE
_ZONEALGORITHM.fields_by_name['current_objects_counter'].message_type = _ZONEALGORITHM_CURRENTOBJECTSCOUNTER
_ZONEALGORITHM.fields_by_name['pass_through_counter'].message_type = _ZONEALGORITHM_PASSTHROUGHCOUNTER
_ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'].message_type = _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER
_ZONEALGORITHM.fields_by_name['security'].message_type = _ZONEALGORITHM_SECURITY
_ZONEALGORITHM.fields_by_name['occupancy'].message_type = _ZONEALGORITHM_OCCUPANCY
_ZONEALGORITHM.fields_by_name['volume'].message_type = _ZONEALGORITHM_VOLUME
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['current_objects_counter'])
_ZONEALGORITHM.fields_by_name['current_objects_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['pass_through_counter'])
_ZONEALGORITHM.fields_by_name['pass_through_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'])
_ZONEALGORITHM.fields_by_name['appearance_disappearance_counter'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['security'])
_ZONEALGORITHM.fields_by_name['security'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['occupancy'])
_ZONEALGORITHM.fields_by_name['occupancy'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
_ZONEALGORITHM.oneofs_by_name['algorithm_type'].fields.append(
  _ZONEALGORITHM.fields_by_name['volume'])
_ZONEALGORITHM.fields_by_name['volume'].containing_oneof = _ZONEALGORITHM.oneofs_by_name['algorithm_type']
DESCRIPTOR.message_types_by_name['ZoneAlgorithm'] = _ZONEALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ZoneAlgorithm = _reflection.GeneratedProtocolMessageType('ZoneAlgorithm', (_message.Message,), {

  'CurrentObjectsCounter' : _reflection.GeneratedProtocolMessageType('CurrentObjectsCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_CURRENTOBJECTSCOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.CurrentObjectsCounter)
    })
  ,

  'PassThroughCounter' : _reflection.GeneratedProtocolMessageType('PassThroughCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_PASSTHROUGHCOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.PassThroughCounter)
    })
  ,

  'AppearanceDisappearanceCounter' : _reflection.GeneratedProtocolMessageType('AppearanceDisappearanceCounter', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_APPEARANCEDISAPPEARANCECOUNTER,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.AppearanceDisappearanceCounter)
    })
  ,

  'Security' : _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_SECURITY,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Security)
    })
  ,

  'Occupancy' : _reflection.GeneratedProtocolMessageType('Occupancy', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_OCCUPANCY,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Occupancy)
    })
  ,

  'Volume' : _reflection.GeneratedProtocolMessageType('Volume', (_message.Message,), {
    'DESCRIPTOR' : _ZONEALGORITHM_VOLUME,
    '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm.Volume)
    })
  ,
  'DESCRIPTOR' : _ZONEALGORITHM,
  '__module__' : 'bf_proto.percept.data.zone_algorithm_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.ZoneAlgorithm)
  })
_sym_db.RegisterMessage(ZoneAlgorithm)
_sym_db.RegisterMessage(ZoneAlgorithm.CurrentObjectsCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.PassThroughCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.AppearanceDisappearanceCounter)
_sym_db.RegisterMessage(ZoneAlgorithm.Security)
_sym_db.RegisterMessage(ZoneAlgorithm.Occupancy)
_sym_db.RegisterMessage(ZoneAlgorithm.Volume)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/data/imu.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/data/imu.proto',
  package='blickfeld.protocol.data',
  syntax='proto2',
  serialized_options=b'\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18\x62lickfeld/data/imu.proto\x12\x17\x62lickfeld.protocol.data\x1a\x17\x62lickfeld/options.proto\"\xdf\x02\n\x03IMU\x12\x1b\n\rstart_time_ns\x18\x01 \x01(\x04\x42\x04\xb0\xb5\x18\x01\x12:\n\x07samples\x18\x02 \x03(\x0b\x32#.blickfeld.protocol.data.IMU.SampleB\x04\xb0\xb5\x18\x01\x12\x39\n\x06packed\x18\x03 \x01(\x0b\x32#.blickfeld.protocol.data.IMU.PackedB\x04\xb0\xb5\x18\x01\x1a\x61\n\x06Sample\x12\x17\n\x0fstart_offset_ns\x18\x01 \x01(\x04\x12\x1c\n\x0c\x61\x63\x63\x65leration\x18\x02 \x03(\x02\x42\x06\x10\x01\xa0\xb5\x18\x06\x12 \n\x10\x61ngular_velocity\x18\x03 \x03(\x02\x42\x06\x10\x01\xa0\xb5\x18\x06\x1a\x61\n\x06Packed\x12\x0e\n\x06length\x18\x01 \x01(\r\x12\x17\n\x0fstart_offset_ns\x18\x02 \x01(\x0c\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x0c\x12\x18\n\x10\x61ngular_velocity\x18\x04 \x01(\x0c\x42\x03\xf8\x01\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,])




_IMU_SAMPLE = _descriptor.Descriptor(
  name='Sample',
  full_name='blickfeld.protocol.data.IMU.Sample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_offset_ns', full_name='blickfeld.protocol.data.IMU.Sample.start_offset_ns', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='blickfeld.protocol.data.IMU.Sample.acceleration', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001\240\265\030\006', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='blickfeld.protocol.data.IMU.Sample.angular_velocity', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001\240\265\030\006', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=331,
)

_IMU_PACKED = _descriptor.Descriptor(
  name='Packed',
  full_name='blickfeld.protocol.data.IMU.Packed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='blickfeld.protocol.data.IMU.Packed.length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_offset_ns', full_name='blickfeld.protocol.data.IMU.Packed.start_offset_ns', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='blickfeld.protocol.data.IMU.Packed.acceleration', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='blickfeld.protocol.data.IMU.Packed.angular_velocity', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=430,
)

_IMU = _descriptor.Descriptor(
  name='IMU',
  full_name='blickfeld.protocol.data.IMU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time_ns', full_name='blickfeld.protocol.data.IMU.start_time_ns', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples', full_name='blickfeld.protocol.data.IMU.samples', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packed', full_name='blickfeld.protocol.data.IMU.packed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IMU_SAMPLE, _IMU_PACKED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=430,
)

_IMU_SAMPLE.containing_type = _IMU
_IMU_PACKED.containing_type = _IMU
_IMU.fields_by_name['samples'].message_type = _IMU_SAMPLE
_IMU.fields_by_name['packed'].message_type = _IMU_PACKED
DESCRIPTOR.message_types_by_name['IMU'] = _IMU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IMU = _reflection.GeneratedProtocolMessageType('IMU', (_message.Message,), {

  'Sample' : _reflection.GeneratedProtocolMessageType('Sample', (_message.Message,), {
    'DESCRIPTOR' : _IMU_SAMPLE,
    '__module__' : 'blickfeld.data.imu_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.IMU.Sample)
    })
  ,

  'Packed' : _reflection.GeneratedProtocolMessageType('Packed', (_message.Message,), {
    'DESCRIPTOR' : _IMU_PACKED,
    '__module__' : 'blickfeld.data.imu_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.IMU.Packed)
    })
  ,
  'DESCRIPTOR' : _IMU,
  '__module__' : 'blickfeld.data.imu_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.data.IMU)
  })
_sym_db.RegisterMessage(IMU)
_sym_db.RegisterMessage(IMU.Sample)
_sym_db.RegisterMessage(IMU.Packed)


DESCRIPTOR._options = None
_IMU_SAMPLE.fields_by_name['acceleration']._options = None
_IMU_SAMPLE.fields_by_name['angular_velocity']._options = None
_IMU.fields_by_name['start_time_ns']._options = None
_IMU.fields_by_name['samples']._options = None
_IMU.fields_by_name['packed']._options = None
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Language(_Language, metaclass=_LanguageEnumTypeWrapper):
    pass
class _Language:
    V = typing.NewType('V', builtins.int)
class _LanguageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Language.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    CPP = Language.V(1)
    PYTHON = Language.V(2)
    TYPESCRIPT = Language.V(3)

CPP = Language.V(1)
PYTHON = Language.V(2)
TYPESCRIPT = Language.V(3)
global___Language = Language


class ValueRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MINIMUM_FIELD_NUMBER: builtins.int
    MAXIMUM_FIELD_NUMBER: builtins.int
    minimum: builtins.float = ...
    maximum: builtins.float = ...
    def __init__(self,
        *,
        minimum : typing.Optional[builtins.float] = ...,
        maximum : typing.Optional[builtins.float] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> None: ...
global___ValueRange = ValueRange

class OptionalValueRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MINIMUM_FIELD_NUMBER: builtins.int
    MAXIMUM_FIELD_NUMBER: builtins.int
    minimum: builtins.float = ...
    maximum: builtins.float = ...
    def __init__(self,
        *,
        minimum : typing.Optional[builtins.float] = ...,
        maximum : typing.Optional[builtins.float] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> None: ...
global___OptionalValueRange = OptionalValueRange

class SoftwareVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    CI_JOB_ID_FIELD_NUMBER: builtins.int
    name: typing.Text = ...
    """Tag or reference name of the version. It is not the the name of the software."""

    revision: typing.Text = ...
    """The GIT revision of the software version if available."""

    ci_job_id: builtins.int = ...
    """The unique continuous integration job ID if available."""

    def __init__(self,
        *,
        name : typing.Optional[typing.Text] = ...,
        revision : typing.Optional[typing.Text] = ...,
        ci_job_id : typing.Optional[builtins.int] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"ci_job_id",b"ci_job_id",u"name",b"name",u"revision",b"revision"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ci_job_id",b"ci_job_id",u"name",b"name",u"revision",b"revision"]) -> None: ...
global___SoftwareVersion = SoftwareVersion

class HardwareModule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    LEGACY_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    serial_number: typing.Text = ...
    """Serial number of the hardware module"""

    legacy_serial_number: typing.Text = ...
    """Deprecated legacy serial number format"""

    version: typing.Text = ...
    """Hardware version of the hardware module if available."""

    def __init__(self,
        *,
        serial_number : typing.Optional[typing.Text] = ...,
        legacy_serial_number : typing.Optional[typing.Text] = ...,
        version : typing.Optional[typing.Text] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"legacy_serial_number",b"legacy_serial_number",u"serial_number",b"serial_number",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"legacy_serial_number",b"legacy_serial_number",u"serial_number",b"serial_number",u"version",b"version"]) -> None: ...
global___HardwareModule = HardwareModule

class Field(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.14 and firmware v1.14

    Describes a protobuf field inside a (nested) message to efficiently use reflection on all supported platforms
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Identifier(google.protobuf.message.Message):
        """Describes unique identifier of (sub) field"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ID_FIELD_NUMBER: builtins.int
        KEY_FIELD_NUMBER: builtins.int
        CAMELCASE_KEY_FIELD_NUMBER: builtins.int
        id: builtins.int = ...
        """Protobuf number of field"""

        key: typing.Text = ...
        """Protobuf key of field"""

        camelcase_key: typing.Text = ...
        """Protobuf camelcase key of field"""

        def __init__(self,
            *,
            id : typing.Optional[builtins.int] = ...,
            key : typing.Optional[typing.Text] = ...,
            camelcase_key : typing.Optional[typing.Text] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"camelcase_key",b"camelcase_key",u"id",b"id",u"key",b"key"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"camelcase_key",b"camelcase_key",u"id",b"id",u"key",b"key"]) -> None: ...

    IDENTIFIERS_FIELD_NUMBER: builtins.int
    SCALE_FIELD_NUMBER: builtins.int
    @property
    def identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Field.Identifier]:
        """Path to field in relation to given top level message."""
        pass
    scale: builtins.float = ...
    """Numerical scale which is applied on a field value before using it for validation.
    This is required to prevent floating point precision issues due to rounding, which could fail a validation.<br>
    Validation example:
    Field value is stored as radian but is shown to the user as degree.
    Without scaling and rounding, a possible degree format could be rejected as it exceeded the maximum value of the radian respresentation after down-scaling.
    """

    def __init__(self,
        *,
        identifiers : typing.Optional[typing.Iterable[global___Field.Identifier]] = ...,
        scale : typing.Optional[builtins.float] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"scale",b"scale"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"identifiers",b"identifiers",u"scale",b"scale"]) -> None: ...
global___Field = Field

class Constraint(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.14 and firmware v1.14

    Describes a constraint for a single target field
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Constant(google.protobuf.message.Message):
        """Constant constraint which is used to apply min and/or max ranges"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MINIMUM_FIELD_NUMBER: builtins.int
        MAXIMUM_FIELD_NUMBER: builtins.int
        minimum: builtins.float = ...
        """Target value must be equals or higher than the specified minimum"""

        maximum: builtins.float = ...
        """Target value must be equals or smaller than the specified maximum"""

        def __init__(self,
            *,
            minimum : typing.Optional[builtins.float] = ...,
            maximum : typing.Optional[builtins.float] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum"]) -> None: ...

    class Polynomial(google.protobuf.message.Message):
        """Polynomial constraint which describe a value relationship to another field"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        REFERENCE_FIELD_NUMBER: builtins.int
        MINIMUM_FIELD_NUMBER: builtins.int
        MAXIMUM_FIELD_NUMBER: builtins.int
        @property
        def reference(self) -> global___Field:
            """Link to reference field. The value of the reference field is used as x input for the polynomial."""
            pass
        @property
        def minimum(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Target value must be equals or higher than the specified minimum, which is described by the specified repeated coefficients: c0 + x * c1 + x^2 * c2 .."""
            pass
        @property
        def maximum(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Target value must be equals or smaller than the specified maximum, which is described by the specified repeated coefficients: c0 + x * c1 + x^2 * c2 .."""
            pass
        def __init__(self,
            *,
            reference : typing.Optional[global___Field] = ...,
            minimum : typing.Optional[typing.Iterable[builtins.float]] = ...,
            maximum : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"reference",b"reference"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"maximum",b"maximum",u"minimum",b"minimum",u"reference",b"reference"]) -> None: ...

    TARGET_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    CONSTANT_FIELD_NUMBER: builtins.int
    POLYNOMIAL_FIELD_NUMBER: builtins.int
    @property
    def target(self) -> global___Field:
        """Link to target field on which the contraint is applied"""
        pass
    reason: typing.Text = ...
    """Human-readable reason for the constraint and its failure"""

    @property
    def constant(self) -> global___Constraint.Constant: ...
    @property
    def polynomial(self) -> global___Constraint.Polynomial: ...
    def __init__(self,
        *,
        target : typing.Optional[global___Field] = ...,
        reason : typing.Optional[typing.Text] = ...,
        constant : typing.Optional[global___Constraint.Constant] = ...,
        polynomial : typing.Optional[global___Constraint.Polynomial] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"constant",b"constant",u"polynomial",b"polynomial",u"reason",b"reason",u"target",b"target",u"type",b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"constant",b"constant",u"polynomial",b"polynomial",u"reason",b"reason",u"target",b"target",u"type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"type",b"type"]) -> typing.Optional[typing_extensions.Literal["constant","polynomial"]]: ...
global___Constraint = Constraint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bf_proto.percept.common.geometry_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Shape(google.protobuf.message.Message):
    """*
    A shape that represent a geometrical figure.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Box(google.protobuf.message.Message):
        """*
        A 3 dimensional box.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        DIMENSIONS_FIELD_NUMBER: builtins.int
        @property
        def dimensions(self) -> bf_proto.percept.common.geometry_pb2.Vector3:
            """The X, Y and Z dimension"""
            pass
        def __init__(self,
            *,
            dimensions : typing.Optional[bf_proto.percept.common.geometry_pb2.Vector3] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"dimensions",b"dimensions"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"dimensions",b"dimensions"]) -> None: ...

    POSE_FIELD_NUMBER: builtins.int
    BOX_FIELD_NUMBER: builtins.int
    @property
    def pose(self) -> bf_proto.percept.common.geometry_pb2.Pose:
        """Position and orientation of the center of the bounding box enclosing the shape."""
        pass
    @property
    def box(self) -> global___Shape.Box: ...
    def __init__(self,
        *,
        pose : typing.Optional[bf_proto.percept.common.geometry_pb2.Pose] = ...,
        box : typing.Optional[global___Shape.Box] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"box",b"box",u"pose",b"pose",u"shape_type",b"shape_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"box",b"box",u"pose",b"pose",u"shape_type",b"shape_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"shape_type",b"shape_type"]) -> typing.Optional[typing_extensions.Literal["box"]]: ...
global___Shape = Shape



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Generate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Targets(_Targets, metaclass=_TargetsEnumTypeWrapper):
        """*
        Internal use only
        """
        pass
    class _Targets:
        V = typing.NewType('V', builtins.int)
    class _TargetsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Targets.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        DEFAULT = Generate.Targets.V(0)
        PROTO_HASH = Generate.Targets.V(1)
        MATLAB_BUS = Generate.Targets.V(2)
        CSTRUCT = Generate.Targets.V(3)

    DEFAULT = Generate.Targets.V(0)
    PROTO_HASH = Generate.Targets.V(1)
    MATLAB_BUS = Generate.Targets.V(2)
    CSTRUCT = Generate.Targets.V(3)

    TARGETS_FIELD_NUMBER: builtins.int
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Generate.Targets.V]:
        """Internal generate targets"""
        pass
    def __init__(self,
        *,
        targets : typing.Optional[typing.Iterable[global___Generate.Targets.V]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"targets",b"targets"]) -> None: ...
global___Generate = Generate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import blickfeld.config.generate_pb2
import blickfeld.config.secure_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

optional_one_of: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.OneofOptions, builtins.bool] = ...

d_min: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.float] = ...

d_max: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.float] = ...

length: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.int] = ...

regex: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, typing.Text] = ...

optional: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool] = ...

allow_sparse: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool] = ...

min_length: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.int] = ...

max_length: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.int] = ...

legacy_field_id: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.int] = ...

unit: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, typing.Text] = ...
"""Unit of field value"""

ui_unit: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, typing.Text] = ...
"""Unit of field value in user interfaces (UIs)."""

ui_scale: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.float] = ...
"""Scaling of field value in user interfaces (UIs). Example: rad-to-degree conversions."""

ui_decimal_places: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.int] = ...

e_desc: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, typing.Text] = ...
"""Error description"""

help: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, typing.Text] = ...
"""Help description"""

secure: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, blickfeld.config.secure_pb2.Secure] = ...

generate: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, blickfeld.config.generate_pb2.Generate] = ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Point(google.protobuf.message.Message):
    """*
    This section describes the contents of a single point of a point cloud frame or scan line.
    Each point resembles a direction in which the laser has fired.
    From each point (direction) the device can receive several responses/returns, see [Point.Return](#blickfeld.protocol.data.Point.Return).
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ErrorFlag(_ErrorFlag, metaclass=_ErrorFlagEnumTypeWrapper):
        """*
        Error flag indicating why a point delivers no valid returns.
        If a flag is set, the point should not be interpreted neither processed.
        Flags are only set temporarily for a short period of time.
        If the error state does not recover, the device will stop operation.
        """
        pass
    class _ErrorFlag:
        V = typing.NewType('V', builtins.int)
    class _ErrorFlagEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ErrorFlag.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        E_VIBRATION_THRESHOLD_EXCEEDED = Point.ErrorFlag.V(1)
        """The environmental vibration threshold was exceeded. This should not happen in normal operation."""


    E_VIBRATION_THRESHOLD_EXCEEDED = Point.ErrorFlag.V(1)
    """The environmental vibration threshold was exceeded. This should not happen in normal operation."""


    class Return(google.protobuf.message.Message):
        """*
        This section describes the contents of a single return of a point, sorted by intensity.
        A return is created when the LiDAR detects the laser light of the reflection of an object.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ID_FIELD_NUMBER: builtins.int
        CARTESIAN_FIELD_NUMBER: builtins.int
        RANGE_FIELD_NUMBER: builtins.int
        INTENSITY_FIELD_NUMBER: builtins.int
        id: builtins.int = ...
        """ID of the return in the point"""

        @property
        def cartesian(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Unit: [m] – Cartesian coordinates of the target [x,y,z]"""
            pass
        range: builtins.float = ...
        """Unit: [m] – distance of target to the origin"""

        intensity: builtins.int = ...
        """Intensity of the returned laser pulse"""

        def __init__(self,
            *,
            id : typing.Optional[builtins.int] = ...,
            cartesian : typing.Optional[typing.Iterable[builtins.float]] = ...,
            range : typing.Optional[builtins.float] = ...,
            intensity : typing.Optional[builtins.int] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"id",b"id",u"intensity",b"intensity",u"range",b"range"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"cartesian",b"cartesian",u"id",b"id",u"intensity",b"intensity",u"range",b"range"]) -> None: ...

    class Direction(google.protobuf.message.Message):
        """*
        This section describes the direction and the origin of a point.
        Use these polar coordinates combined with the range information of a given return, if you want to locate the reflection in the spherical coordinatesystem.
        """
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        AZIMUTH_FIELD_NUMBER: builtins.int
        ELEVATION_FIELD_NUMBER: builtins.int
        ORIGIN_FIELD_NUMBER: builtins.int
        azimuth: builtins.float = ...
        """Unit: [rad] - azimuth angle: Angle with respect to y-z plane"""

        elevation: builtins.float = ...
        """Unit: [rad] - elevation angle: Angle with respect to x-y plane"""

        @property
        def origin(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
            """Unit: [m] - origin of the laser beam [x,y,z]"""
            pass
        def __init__(self,
            *,
            azimuth : typing.Optional[builtins.float] = ...,
            elevation : typing.Optional[builtins.float] = ...,
            origin : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"azimuth",b"azimuth",u"elevation",b"elevation"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"azimuth",b"azimuth",u"elevation",b"elevation",u"origin",b"origin"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    RETURNS_FIELD_NUMBER: builtins.int
    START_OFFSET_NS_FIELD_NUMBER: builtins.int
    AMBIENT_LIGHT_LEVEL_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    ERROR_FLAGS_FIELD_NUMBER: builtins.int
    id: builtins.int = ...
    """Point ID in the corresponding frame"""

    @property
    def returns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Point.Return]:
        """Refer to [Point.Return](#blickfeld.protocol.data.Point.Return)"""
        pass
    start_offset_ns: builtins.int = ...
    """Unit: [ns] - starting time of the point in relation to [Frame.start_time_ns](#blickfeld.protocol.data.Frame.start_time_ns)"""

    ambient_light_level: builtins.int = ...
    """Ambient light level in the direction of the point"""

    @property
    def direction(self) -> global___Point.Direction:
        """Refer to [Point.Direction](#blickfeld.protocol.data.Point.Direction)"""
        pass
    channel_id: builtins.int = ...
    """ID of the channel that detected the point"""

    @property
    def error_flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Point.ErrorFlag.V]:
        """Refer to [Point.ErrorFlag](#blickfeld.protocol.data.Point.ErrorFlag)"""
        pass
    def __init__(self,
        *,
        id : typing.Optional[builtins.int] = ...,
        returns : typing.Optional[typing.Iterable[global___Point.Return]] = ...,
        start_offset_ns : typing.Optional[builtins.int] = ...,
        ambient_light_level : typing.Optional[builtins.int] = ...,
        direction : typing.Optional[global___Point.Direction] = ...,
        channel_id : typing.Optional[builtins.int] = ...,
        error_flags : typing.Optional[typing.Iterable[global___Point.ErrorFlag.V]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"channel_id",b"channel_id",u"direction",b"direction",u"id",b"id",u"start_offset_ns",b"start_offset_ns"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ambient_light_level",b"ambient_light_level",u"channel_id",b"channel_id",u"direction",b"direction",u"error_flags",b"error_flags",u"id",b"id",u"returns",b"returns",u"start_offset_ns",b"start_offset_ns"]) -> None: ...
global___Point = Point
